@@ -12,7 +12,7 @@ our @EXPORT_OK = qw(
 
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 sub LEFT_BUTTON   { return 0 }
 sub MIDDLE_BUTTON { return 1 }
@@ -26,7 +26,7 @@ Firefox::Marionette::Buttons - Human readable mouse buttons for the Marionette p
 
 =head1 VERSION
 
-Version 1.11
+Version 1.12
 
 =head1 SYNOPSIS
 
@@ -79,11 +79,7 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-firefox-marionette@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+To report a bug, or view the current list of bugs, please visit L<https://github.com/david-dick/firefox-marionette/issues>
 
 =head1 AUTHOR
 
