@@ -11,7 +11,7 @@ BEGIN {
         require Win32;
     }
 }
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 sub profile_ini_directory {
     my ($class) = @_;
@@ -101,7 +101,7 @@ Waterfox::Marionette::Profile - Represents a prefs.js Waterfox Profile
 
 =head1 VERSION
 
-Version 1.11
+Version 1.12
 
 =head1 SYNOPSIS
 
@@ -162,11 +162,7 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-firefox-marionette@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+To report a bug, or view the current list of bugs, please visit L<https://github.com/david-dick/firefox-marionette/issues>
 
 =head1 AUTHOR
 
